@@ -381,8 +381,7 @@ def virtual_ssl_echo_server(
     yield SSLStream(fakesock, client_ctx, server_hostname="trio-test-1.example.org")
 
 
-# Explicit "Any" is not allowed
-def ssl_wrap_pair(  # type: ignore[misc]
+def ssl_wrap_pair(  # type: ignore[explicit-any]
     client_ctx: SSLContext,
     client_transport: T_Stream,
     server_transport: T_Stream,
